# Generated by Django 3.0.10 on 2020-11-22 09:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0006_icon'),
    ]

    operations = [

    ]
